%define module   Context-Preserve

Name:       perl-%{module}
Version:    0.01
Release:    %mkrel 7
License:    GPL or Artistic
Group:      Development/Perl
Summary:    Run code after a subroutine call, preserving the context the subroutine would have seen if it were the last statement in the caller
Url:        http://search.cpan.org/dist/%{module}
Source:     http://www.cpan.org/modules/by-module/Context/%{module}-%{version}.tar.gz
BuildRequires: perl(Exporter)
BuildRequires: perl(Test::Exception)
BuildRequires: perl(Test::More)
BuildRequires: perl-Test-use-ok
BuildArch: noarch


%{?perl_default_filter}

%description
Sometimes you need to call a function, get the results, act on the results,
then return the result of the function. This is painful because of
contexts; the original function can behave different if it's called in
void, scalar, or list context. You can ignore the various cases and just
pick one, but that's fragile. To do things right, you need to see which
case you're being called in, and then call the function in that context.
This results in 3 code paths, which is a pain to type in (and maintain).

This module automates the process. You provide a coderef that is the
"original function", and another coderef to run after the original runs.
You can modify the return value (aliased to @_) here, and do whatever else
you need to do. 'wantarray' is correct inside both coderefs; in "after",
though, the return value is ignored and the value 'wantarray' returns is
related to the context that the original function was called in.



%prep
%setup -q -n %{module}-%{version} 

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%make

%check
make test

%install
%makeinstall_std

%files
%doc README Changes META.yml
%{_mandir}/man3/*
%perl_vendorlib/*


%changelog
* Wed Oct 15 2014 umeabot <umeabot> 0.01-7.mga5
+ Revision: 747026
- Second Mageia 5 Mass Rebuild

* Tue Sep 30 2014 tv <tv> 0.01-6.mga5
+ Revision: 732959
- add exclude

* Tue Sep 16 2014 umeabot <umeabot> 0.01-5.mga5
+ Revision: 684007
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 0.01-4.mga4
+ Revision: 510306
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 umeabot <umeabot> 0.01-3.mga3
+ Revision: 364734
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Jan 21 2011 jquelin <jquelin> 0.01-2.mga1
+ Revision: 28436
- mageia rebuild
- cleaning spec file
- imported package perl-Context-Preserve

